@@ -8,14 +8,19 @@ T = TypeVar('T')
 
 class AutopropGetter(Generic[T], AutopropBase):
 
-    __slots__ = ('__auto_prop__', '__prop_attr_name__', '__method_type__', '__prop_name__')
+    __slots__ = (
+        '__auto_prop__', 
+        '__prop_attr_name__', 
+        '__method_type__', 
+        '__prop_name__'
+    )
 
     def __init__(self, prop_name: str,  attr_name: str, belong: IAutoProperty):
         super().__init__(prop_name, attr_name, belong, AutoPropType.Getter)
         return
    
     def __call__(self,  cls: object, owner=None):
-        self.__get__(cls)
+        return self.__get__(cls)
     
     def __get__(self, instance, owner=None):
         return getattr(instance, self.__prop_attr_name__, None)
